@@ -21,7 +21,9 @@ def load_metadata_before(func):
 class LocalRepo(Recycle, _SharedAPI):
     """ Tools to help Path interface a Local Python Repository.
         Todo: Search for imports to list dependencies. """
+
     enabled = True
+    private = False
     name = ...
     version = "0.0.1"  # type: Ver
     description = "Missing description."
@@ -133,19 +135,22 @@ class LocalRepo(Recycle, _SharedAPI):
         """ Set a metadata's key both in instance and json file. """
         if self.has_metadata() and value != getattr(self, f"_{key}", ...):
             metadata = self.get_metadata_path().read()
-            metadata[key] = str(value)
+            metadata[key] = str(value) if key == "version" else value  # Todo: Decoupled JSON serialize instructions with custom dumps in lib.
             self.get_metadata_path().write(metadata, overwrite=True, indent=4)
         setattr(self, f"_{key}", value)
 
-    def get_readme_path(self):      return self.path / "README.md"
-    def get_metadata_path(self):    return self.path / "metadata.json"
-    def get_git_exclude_path(self): return self.path / ".git/info/exclude"
-    def get_setup_path(self):       return self.path / "setup.py"
-    def get_manifest_path(self):    return self.path / "MANIFEST.in"
-    def get_license_path(self):     return self.path / "LICENSE"
-    def get_workflow_path(self):    return self.path / ".github/workflows/workflow.yml"
-    def get_test_path(self):        return self.path / f"{self.name}/test"
-    def get_init_path(self):        return self.path / self.name / "__init__.py"
+    def get_readme_path(self):              return self.path / "README.md"
+    def get_org_readme_path(self):          return self.path / "profile/README.md"
+    def get_metadata_path(self):            return self.path / "metadata.json"
+    def get_git_exclude_path(self):         return self.path / ".git/info/exclude"
+    def get_setup_path(self):               return self.path / "setup.py"
+    def get_manifest_path(self):            return self.path / "MANIFEST.in"
+    def get_license_path(self):             return self.path / "LICENSE"
+    def get_workflow_path(self):            return self.path / ".github/workflows/workflow.yml"
+    def get_test_path(self):                return self.path / f"{self.name}/test"
+    def get_test_template_path(self):       return self.get_test_path() / f"test_{self.name}.py"
+    def get_init_path(self):                return self.path / self.name / "__init__.py"
+    def get_randomtesting_path(self):       return self.path / "randomtesting.py"
 
     @deco_cache()
     def get_test_paths(self):
@@ -199,6 +204,9 @@ class LocalRepo(Recycle, _SharedAPI):
     def upload(self):
         """ Upload local repo to PyPI.
             Todo: Make sure twine is installed when trying to upload to pypi. """
+        if self.private:
+            raise AttributeError("Cannot upload private repo.")
+
         self.create_sdist()
         with self.path.as_working_dir():
             terminal("-m", "twine", "upload", "dist/*", python=True)
