@@ -1,6 +1,6 @@
 
 from generalpackager.api.shared import _SharedAPI
-from generallibrary import Ver, Date, Recycle
+from generallibrary import Ver, Date, Recycle, get
 from generalfile import Path
 
 import requests
@@ -62,15 +62,16 @@ class PyPI(Recycle, _SharedAPI):
         """ Get a set of a owner's packages' names on PyPI. """
         return set(re.findall("/project/(.*)/", requests.get(f"https://pypi.org/user/{self.owner}/").text))
 
+    # Todo: Find a faster fetch for latest PyPI version and datetime.
     def get_version(self):
-        """ Get version of latest publish on PyPI.
-            Todo: Find a faster fetch for latest PyPI version. """
-        return Ver(re.findall(f"{self.name} ([.0-9]+)\n", requests.get(self.url).text)[0])
+        """ Get version of latest publish on PyPI. """
+        version = get(re.findall(f"{self.name} ([.0-9]+)\n", requests.get(self.url).text), 0)
+        return Ver(version) if version else None
 
     def get_date(self):
-        """ Get datetime of latest release.
-            Todo: Find a faster fetch for latest PyPI datetime. """
-        return Date(re.findall('Generated (.+) for commit', requests.get(self.url).text)[0])
+        """ Get datetime of latest release. """
+        date = get(re.findall('Generated (.+) for commit', requests.get(self.url).text), 0)
+        return Date(date) if date else None
 
     def reserve_name(self):
         pass  # HERE **
